# PointOfPresenceRouting

Describes how a point of presence may be accessed over the Internet. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**domains** | [**[Domain]**](Domain.md) | The domains that address this point of presence. Use these when configuring external systems such as a DNS CNAME or a firewall.  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


